"use client"

import React, { useRef, useState } from "react";
import { RiArrowDropDownLine } from "react-icons/ri";


interface AccordionItemProps {
    question: string;
    answer: string;
    isOpen: boolean;
    onClick: () => void;
}

const AccordionItem: React.FC<AccordionItemProps> = ({
    question,
    answer,
    isOpen,
    onClick,
}) => {
    const contentHeight = useRef<HTMLDivElement>(null);

    return (
        <div className="wrapper overflow-hidden rounded-3xl bg-stone_opacity-400 backdrop-blur-sm">
            <button
                className={`question-container font-medium text-lg p-6 w-full text-left flex items-center justify-between cursor-pointer hover:saturate-[1.2] hover:text-orange-500 transition ${isOpen ? "active" : ""}`}
                onClick={onClick}
            >
                <p className="question-content w-[80%]">{question}</p>
                <div className="bg-orange-400 w-7 h-7 rounded-lg p-2 flex items-center justify-center">
                    <svg className={`arrow ${isOpen ? "rotate-180" : ""}`} width="14" height="14" viewBox="0 0 14 14" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M11.6848 5.55953L7.30977 9.93453C7.26914 9.97521 7.22089 10.0075 7.16778 10.0295C7.11467 10.0515 7.05774 10.0628 7.00024 10.0628C6.94275 10.0628 6.88582 10.0515 6.83271 10.0295C6.7796 10.0075 6.73134 9.97521 6.69071 9.93453L2.31571 5.55953C2.23362 5.47744 2.1875 5.3661 2.1875 5.25C2.1875 5.1339 2.23362 5.02256 2.31571 4.94047C2.3978 4.85837 2.50915 4.81226 2.62524 4.81226C2.74134 4.81226 2.85268 4.85837 2.93477 4.94047L7.00024 9.00648L11.0657 4.94047C11.1064 4.89982 11.1546 4.86758 11.2077 4.84558C11.2608 4.82358 11.3178 4.81226 11.3752 4.81226C11.4327 4.81226 11.4897 4.82358 11.5428 4.84558C11.5959 4.86758 11.6441 4.89982 11.6848 4.94047C11.7254 4.98112 11.7577 5.02937 11.7797 5.08248C11.8017 5.13559 11.813 5.19251 11.813 5.25C11.813 5.30748 11.8017 5.36441 11.7797 5.41752C11.7577 5.47063 11.7254 5.51888 11.6848 5.55953Z" fill="#1C1917" />
                    </svg>
                </div>
            </button>

            <div
                ref={contentHeight}
                className="answer-container"
                style={
                    isOpen
                        ? { height: contentHeight.current?.scrollHeight }
                        : { height: "0px" }
                }
            >
                <p className="answer-content p-6 md:pl-16 leading-relaxed">{answer}</p>
            </div>
        </div>
    );
};

interface AccordionProps {
    data: { question: string; answer: string }[];
}

const Accordion: React.FC<AccordionProps> = ({ data }) => {
    const [activeIndex, setActiveIndex] = useState<number | null>(null);

    const handleItemClick = (index: number) => {
        setActiveIndex((prevIndex) => (prevIndex === index ? null : index));
    };

    return (
        <div className="container flex flex-col gap-3 max-w-[650px] w-full">
            {data.map((item, index) => (
                <AccordionItem
                    key={index}
                    question={item.question}
                    answer={item.answer}
                    isOpen={activeIndex === index}
                    onClick={() => handleItemClick(index)}
                />
            ))}
        </div>
    );
};

export default Accordion;